@@ -1,4 +1,4 @@
-__version__ = "1.2.1"
+__version__ = "2.0.0"
 __url__ = "https://zeus-mcmc.readthedocs.io"
 __author__ = "Minas Karamanis"
 __email__ = "minaskar@gmail.com"
@@ -7,6 +7,6 @@ __description__ = "Lightning Fast MCMC"
 
 
 from .ensemble import *
-from .diagnostics import GelmanRubin, Geweke
 from .parallel import ChainManager
-from .autocorr import AutoCorrTime
\ No newline at end of file
+from .autocorr import AutoCorrTime
+from .plotting import cornerplot
\ No newline at end of file
